---
title: How to use markdown and MDX in Next.js
nav_title: MDX
description: Learn how to configure MDX to write JSX in your markdown files.
source: app/guides/mdx
---

{/* DO NOT EDIT. The content of this doc is generated from the source above. To edit the content of this page, navigate to the source page in your editor. You can use the `<PagesOnly>Content</PagesOnly>` component to add content that is specific to the Pages Router. Any shared content should not be wrapped in a component. */}
